@@ -1,5 +1,9 @@
-package App::DistSync; # $Id: DistSync.pm 25 2017-08-29 09:21:01Z abalama $
+package App::DistSync; # $Id: DistSync.pm 27 2019-07-23 11:26:37Z abalama $
+use warnings;
 use strict;
+use utf8;
+
+=encoding utf-8
 
 =head1 NAME
 
@@ -7,19 +11,19 @@ App::DistSync - Utility synchronization of the mirror distribution-sites
 
 =head1 VERSION
 
-Version 1.05
+Version 1.06
 
 =head1 SYNOPSIS
 
     use App::DistSync;
-    
+
     my $ds = new App::DistSync(
             dir => "/var/www/www.example.com/dist",
             pid => $$,
         );
 
     $ds->init or die ("Initialization error");
-    
+
     $ds->sync or die ("Sync error");
 
 =head1 DESCRIPTION
@@ -28,7 +32,7 @@ Utility synchronization of the mirror distribution-sites
 
 =head2 METHODS
 
-=over 8
+=over 4
 
 =item new
 
@@ -55,7 +59,7 @@ Synchronization of the specified directory with the remote resources (mirrors)
 
 =head2 SHARED FUNCTIONS
 
-=over 8
+=over 4
 
 =item fdelete
 
@@ -66,8 +70,8 @@ Deleting a file if it exists
 =item fetch
 
     my $struct = fetch( $URI_STRING, "path/to/file.txt", "/tmp/file.txt" );
-    
-Fetching file from remote resource by URI and filename. 
+
+Fetching file from remote resource by URI and filename.
 The result will be written to the specified file. For example: "/tmp/file.txt"
 
 Function returns structure, contains:
@@ -83,18 +87,36 @@ Function returns structure, contains:
 
     my $status = touch( $file );
 
-Makes files exist, with current timestamp. 
+Makes files exist, with current timestamp.
 See original in L<ExtUtils::Command/touch>
 
 =back
 
+=head2 PRIVATE FUNCTIONS
+
+=over 4
+
+=item debug
+
+show debug information
+
+=item manifind, maniread, maniwrite
+
+Working with manifest file
+
+=item read_yaml, write_yaml
+
+Working with YAML files
+
+=back
+
 =head1 HISTORY
 
-See C<CHANGES> file
+See C<Changes> file
 
 =head1 DEPENDENCIES
 
-L<LWP>
+L<CTK>
 
 =head1 TO DO
 
@@ -106,34 +128,27 @@ See C<TODO> file
 
 =head1 SEE ALSO
 
-C<perl>, L<LWP>, L<ExtUtils::Manifest>
+L<CTK>
 
 =head1 AUTHOR
 
-Serz Minus (Lepenkov Sergey) L<http://www.serzik.com> E<lt>minus@mail333.comE<gt>
+Serż Minus (Sergey Lepenkov) L<http://www.serzik.com> E<lt>abalama@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2014 D&D Corporation. All Rights Reserved
+Copyright (C) 1998-2019 D&D Corporation. All Rights Reserved
 
 =head1 LICENSE
 
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-See C<LICENSE> file
+See C<LICENSE> file and L<https://dev.perl.org/licenses/>
 
 =cut
 
 use vars qw/$VERSION/;
-$VERSION = '1.05';
+$VERSION = '1.06';
 
 use Carp;
 use File::Basename;
@@ -202,7 +217,7 @@ use constant {
             msx => sub { qr{$_[0]}msx },
             msi => sub { qr{$_[0]}msi },
             msix => sub { qr{$_[0]}msix },
-    },    
+    },
 };
 
 our $DEBUG = 0;
@@ -211,11 +226,11 @@ our $DEBUG = 0;
 sub new {
     my $class = shift;
     my %props = @_;
-    
+
     $props{stamp} = time;
     $props{pid} ||= $$;
     $props{timeout} //= TIMEOUT;
-    
+
     # Directories check
     my $dir = $props{dir};
     carp("Can't select directory") && return unless defined $dir;
@@ -228,28 +243,28 @@ sub new {
     $props{file_mirrors}    = File::Spec->catfile($dir, MIRRORS);
     $props{file_readme}     = File::Spec->catfile($dir, README);
     $props{file_temp}       = File::Spec->catfile(File::Spec->tmpdir(), TEMPFILE);
-    
+
     # Read META file as YAML
     my $meta = read_yaml($props{file_meta});
     $props{meta} = $meta;
-    
+
     # Create current static dates
     $props{mtime_manifest} = (-e $props{file_manifest}) && -s $props{file_manifest}
-        ? (stat($props{file_manifest}))[9] 
+        ? (stat($props{file_manifest}))[9]
         : 0;
     $props{mtime_manidel}  = (-e $props{file_manidel}) && -s $props{file_manidel}
-        ? (stat($props{file_manidel}))[9] 
+        ? (stat($props{file_manidel}))[9]
         : 0;
     $props{mtime_mirrors}  = (-e $props{file_mirrors}) && -s $props{file_mirrors}
-        ? (stat($props{file_mirrors}))[9] 
+        ? (stat($props{file_mirrors}))[9]
         : 0;
-    
+
     # Read MANIFEST, MANIFEST.SKIP, MANIFEST.DEL files
     $props{manifest} = maniread($props{file_manifest});
     $props{maniskip} = maniread($props{file_maniskip}, SKIPMODE);
     $props{manidel}  = maniread($props{file_manidel});
     $props{mirrors}  = maniread($props{file_mirrors});
-    
+
     # TimeOut
     my $to = $props{timeout};
     if ($to && $to =~ /^[0-9]{1,11}$/) {
@@ -257,14 +272,14 @@ sub new {
     } else {
         croak(sprintf("Can't use specified timeout value: %s", $to));
     }
-    
+
     my $self = bless({%props}, $class);
     return $self;
 }
 sub init { # Initialization
     my $self = shift;
     my $stamp = scalar(localtime($self->{stamp}));
-    
+
     # MANIFEST.SKIP
     touch($self->{file_maniskip}) or return 0;
     if (-e $self->{file_maniskip} && -z $self->{file_maniskip}) {
@@ -317,7 +332,7 @@ sub init { # Initialization
             ), $stamp;
         close FILE;
     }
-    
+
     # MANIFEST.DEL
     touch($self->{file_manidel}) or return 0;
     if (-e $self->{file_manidel} && -z $self->{file_manidel}) {
@@ -339,7 +354,7 @@ sub init { # Initialization
             ), $stamp;
         close FILE;
     }
-    
+
     # MIRRORS
     touch($self->{file_mirrors}) or return 0;
     if (-e $self->{file_mirrors} && -z $self->{file_mirrors}) {
@@ -359,7 +374,7 @@ sub init { # Initialization
             ), $stamp;
         close FILE;
     }
-    
+
     # README
     touch($self->{file_readme}) or return 0;
     if (-e $self->{file_readme} && -z $self->{file_readme}) {
@@ -374,20 +389,20 @@ sub init { # Initialization
             ), $stamp, $self->{dir};
         close FILE;
     }
-    
+
     return 1;
 }
 sub sync { # Synchronization. Main proccess
     my $self = shift;
-    my $status = 0; #    META
-    
-    #        SKIP +  
+    my $status = 0; # Статус операции для META
+
+    # Создаем список исключений на базе прочитанного ранее SKIP + системные файлы
     my @skip_keys = @{(SKIPFILES)};
     push @skip_keys, keys %{($self->{maniskip})} if ref($self->{maniskip}) eq 'HASH';
     my %skips; for (@skip_keys) {$skips{$_} = _qrreconstruct($_)}
     #debug(Data::Dumper::Dumper(\%skips)) && return 0;
-    
-    #     .DEL
+
+    # Удяляем файлы перечисленные в .DEL
     debug("Deleting of declared files");
     my $dellist = $self->{manidel};
     my $expire = _expire(0);
@@ -404,10 +419,10 @@ sub sync { # Synchronization. Main proccess
     my $delfile = $self->{file_manidel};
     my $deltime = $self->{mtime_manidel};
     if ($deltime && (time - $deltime) > $expire) {
-    
-        #   ,         SKIP !
+
+        # Удаляем файлы физически, если они есть физически и их нет в SKIP файле!
         foreach my $k (keys %$dellist) {
-            if (_skipcheck(\%skips, $k)) { #     
+            if (_skipcheck(\%skips, $k)) { # Файл есть в списке исклюений
                 debug(sprintf("> [SKIPPED] %s", $k));
             } else {
                 my $f = File::Spec->canonpath(File::Spec->catfile($self->{dir}, $k));
@@ -419,9 +434,9 @@ sub sync { # Synchronization. Main proccess
                 }
             }
         }
-        
-        fdelete($delfile); #   MANIFEST.DEL
-        touch($delfile); #    MANIFEST.DEL
+
+        fdelete($delfile); # Удаляем файл MANIFEST.DEL
+        touch($delfile); # Создаем новый файл MANIFEST.DEL
     } else {
         if ($deltime) {
             debug(sprintf("Deleting is skipped. File %s\n\tcreated\t%s;\n\tnow\t%s;\n\texpires\t%s",
@@ -434,30 +449,30 @@ sub sync { # Synchronization. Main proccess
             debug(sprintf("Deleting is skipped. Missing file %s",  MANIDEL))
         }
     }
-    
-    #         SKIP - DEL 
+
+    # Добавляем в список исключений на базе прочитанного ранее SKIP - DEL файлы
     my @del_keys = keys %$dellist if ref($dellist) eq 'HASH';
     for (@del_keys) {$skips{$_} = _qrreconstruct($_)}
-    
+
     ################
-    # 
+    # Синхронизация
     ################
-    my %sync_list;      #  
-    my %delete_list;    #   
-    
-    #  MIRRORS    -    
+    my %sync_list;      # Синхронизационный список
+    my %delete_list;    # Список на удаление
+
+    # Чтение MIRRORS и принятие решения - делать синхронизацию или нет
     debug("Synchronization");
     my $mirror_list = $self->{mirrors};
     my @mirrors = sort {$a cmp $b} keys %$mirror_list if ref($mirror_list) eq 'HASH';
     if (@mirrors) {
         foreach my $url (@mirrors) {
             debug(sprintf("\nRESOURCE %s",$url));
-            
-            #  .LOCK ,    
+
+            # Получение .LOCK файла, пропуск если он имеется
             debug(sprintf("Fetching %s file", MANILOCK));
             my $fetch_lock = fetch($url, MANILOCK, $self->{file_manitemp});
             if ($fetch_lock->{status}) {
-                if ($self->check_lock($self->{file_manitemp})) {
+                if ($self->_check_lock($self->{file_manitemp})) {
                     $self->{uri} = $url;
                     debug("> [SKIPPED] Current resource SHOULD NOT update itself");
                 } else {
@@ -466,8 +481,8 @@ sub sync { # Synchronization. Main proccess
                 next;
             }
             #debug(Data::Dumper::Dumper($fetch_data));
-            
-            #   META     status = 1. ,   
+
+            # Получение удаленного META и анализ его на status = 1. Иначе, пропуск данного ресурса
             debug(sprintf("Fetching %s file", METAFILE));
             my $fetch_meta = fetch($url, METAFILE, $self->{file_manitemp});
             if ($fetch_meta->{status}) {
@@ -477,7 +492,7 @@ sub sync { # Synchronization. Main proccess
                 } elsif ($remote_meta && ref($remote_meta) eq 'HASH') {
                     # OK
                 } else {
-                    debug(Data::Dumper::Dumper(ref($remote_meta),$remote_meta));
+                    #debug(Data::Dumper::Dumper(ref($remote_meta),$remote_meta));
                     debug("> [SKIPPED] Remote resource is unreadable. Please contact the administrator of this resource");
                     next;
                 }
@@ -490,14 +505,14 @@ sub sync { # Synchronization. Main proccess
                         ."\n\tResource:\t%s"
                         ."\n\tDate:\t\t%s"
                         ."\n\tModified:\t%s"
-                        ."\n\tStatus:\t\t%s", 
-                            $remote_uri, 
-                            defined $remote_meta->{date} ? $remote_meta->{date} : 'UNKNOWN', 
-                            $remote_date ? scalar(localtime($remote_date)) : 'UNKNOWN', 
+                        ."\n\tStatus:\t\t%s",
+                            $remote_uri,
+                            defined $remote_meta->{date} ? $remote_meta->{date} : 'UNKNOWN',
+                            $remote_date ? scalar(localtime($remote_date)) : 'UNKNOWN',
                             $remote_ok ? "OK" : "EXPIRED"
                         ));
                     unless ($remote_ok) {
-                        debug(sprintf("> [SKIPPED] Remote resource is expired. Last updated: %s", 
+                        debug(sprintf("> [SKIPPED] Remote resource is expired. Last updated: %s",
                                 $remote_date ? scalar(localtime($remote_date)) : 'UNKNOWN'
                             ));
                         next
@@ -507,17 +522,17 @@ sub sync { # Synchronization. Main proccess
                     next;
                 }
             }
-            
-            #   MANIFEST
+
+            # Получение удаленного MANIFEST
             debug(sprintf("Fetching %s file", MANIFEST));
             my $fetch_mani = fetch($url, MANIFEST, $self->{file_manitemp});
             if ($fetch_mani->{status}) {
-                #     
+                # Читаем файл в отдельную структуру
                 my $remote_manifest = maniread($self->{file_manitemp});
                 my $local_manifest = $self->{manifest};
                 my %mtmp;
-                
-                #      
+
+                # Два списка объединяются во временную структуру
                 foreach my $k (keys(%$local_manifest), keys(%$remote_manifest)) {
                     if ($mtmp{$k}) {
                         my $mt_l = $local_manifest->{$k}[0] || 0;
@@ -528,19 +543,19 @@ sub sync { # Synchronization. Main proccess
                     }
                     #debug(Data::Dumper::Dumper($mt_l,$mt_r));
                 }
-                
-                #     
-                # [<]     
-                # [>]     
-                # [{]  ""   
-                # [}]  ""   
-                # [~]     .     ,
-                #     ..       .
+
+                # Полуаем разницумоих и удаленных файлов
+                # [<] Есть строка в левом файле
+                # [>] есть строка в правом файле
+                # [{] Более "свежий" в левом файле
+                # [}] Более "свежий" в првом файле
+                # [~] Отличаются размеры файлов в строке. Просто вывод информации об этом,
+                #     т.к. более приоритетными являются даты модификации и наличие.
                 #
-                #   :
-                #          1!
-                #   1 -        ,  ?  
-                #  ,    ,   
+                # Сравнение делается так:
+                # пробегамся по полученному хэшу и смотрим где инкремент равен 1!
+                # Там где 1 - значит данный файл есть в одном из файлов, в каком? если
+                # в левом, помечается что в левом, иначе в правом
                 foreach my $k (keys %mtmp) {
                     next unless $mtmp{$k} && $mtmp{$k} == 1;
                     if ($local_manifest->{$k} && $remote_manifest->{$k}) {
@@ -549,11 +564,11 @@ sub sync { # Synchronization. Main proccess
                         if (($mt_l > $mt_r) && ($mt_l - $mt_r) > _expire(LIMIT)) {
                             # debug(sprintf("> [{] %s", $k));
                         } if (($mt_l < $mt_r) && ($mt_r - $mt_l) > _expire(LIMIT)) {
-                            debug(sprintf("> [}] %s (LOC: %s < RMT: %s)", $k, 
+                            debug(sprintf("> [}] %s (LOC: %s < RMT: %s)", $k,
                                     scalar(localtime($mt_l)),
                                     scalar(localtime($mt_r)),
                                 ));
-                            #  ..  
+                            # Скачиваем т.к. там свежее
                             unless (_skipcheck(\%skips, $k)) {
                                 my $ar = $sync_list{$k} || [];
                                 push @$ar, {
@@ -570,7 +585,7 @@ sub sync { # Synchronization. Main proccess
                         # debug(sprintf("> [<] %s", $k));
                     } elsif ($remote_manifest->{$k}) {
                         debug(sprintf("> [>] %s", $k));
-                        # , ..    
+                        # Скачиваем, т.к. у нас такого нет
                         unless (_skipcheck(\%skips, $k)) {
                             my $ar = $sync_list{$k} || [];
                             push @$ar, {
@@ -584,23 +599,23 @@ sub sync { # Synchronization. Main proccess
                         debug(sprintf("> [!] %s", $k));
                     }
                 }
-                $status = 1; #    ,   
+                $status = 1; # Удалось связаться с ресурсом, значит он доступен
             } else {
-                debug(sprintf("> [MISSING] File %s not fetched. Status code: %s", 
+                debug(sprintf("> [MISSING] File %s not fetched. Status code: %s",
                         MANIFEST,
                         $fetch_mani->{code} || 'UNDEFINED',
                     ));
                 #debug(Data::Dumper::Dumper($fetch_mani));
                 next;
             }
-            
-            #   MIRRORS          
+
+            # Пробегаемся по MIRRORS удаленным файлам и добавляем его к общему списку на обновление
             debug(sprintf("Fetching %s file", MIRRORS));
             my $fetch_mirr = fetch($url, MIRRORS, $self->{file_manitemp});
             if ($fetch_mirr->{status} && ((-z $self->{file_mirrors}) || $fetch_mirr->{mtime} > $self->{mtime_mirrors})) {
-                #     
+                # Читаем файл в отдельную структуру
                 my $remote_mirr = maniread($self->{file_manitemp});
-                #    ,       
+                # Добаляем файл на скачку, если там есть два или более зеркал
                 my $mcnt = scalar(keys %$remote_mirr) || 0;
                 if ($mcnt && $mcnt > 1) {
                     my $k = MIRRORS;
@@ -615,12 +630,12 @@ sub sync { # Synchronization. Main proccess
                     debug(sprintf("> [SKIPPED] File %s on %s contains too few mirrors", MIRRORS, $url));
                 }
             }
-            
-            #   .DEL        
+
+            # Пробегаемся по .DEL удаленным файлам и получаем список для принудительного удаления
             debug(sprintf("Fetching %s file", MANIDEL));
             my $fetch_dir = fetch($url, MANIDEL, $self->{file_manitemp});
             if ($fetch_dir->{status}) {
-                #     
+                # Читаем файл в отдельную структуру
                 my $remote_manidel = maniread($self->{file_manitemp});
                 foreach my $k (keys %$remote_manidel) {
                     unless (_skipcheck(\%skips, $k)) {
@@ -633,11 +648,11 @@ sub sync { # Synchronization. Main proccess
         }
     } else {
         carp(sprintf("File %s is empty", MIRRORS));
-        $status = 1; #          
-                     #   
+        $status = 1; # Факт невозможности получить зеркала не является признаком того что ресурс
+                     # отработал с ошибками
     }
-    
-    #     
+
+    # Удаляем принудительно файлы полученного списка
     #debug(Data::Dumper::Dumper(\%delete_list));
     debug("Deleting files");
     foreach my $k (keys %delete_list) {
@@ -649,8 +664,8 @@ sub sync { # Synchronization. Main proccess
             debug(sprintf("> [MISSING] %s (%s)", $k, $f));
         }
     }
-    
-    #   sync_list   ,       
+
+    # Проходим по sync_list и скачиваем файлы, но которых НЕТ в списке на удаление
     debug("Downloading files");
     #debug(Data::Dumper::Dumper(\%sync_list));
     my $total = 0;
@@ -664,7 +679,7 @@ sub sync { # Synchronization. Main proccess
             my $dwldd = 0;
             my $skipped = 0;
             foreach my $job (sort {($b->{mtime} || 0)  <=> ($a->{mtime} || 0)} @$list) {
-                last if $dwldd; # ,  !
+                last if $dwldd; # Выход, если скачали!
                 my $mt_r = $job->{mtime};
                 my $url  = $job->{uri};
                 my $size = $job->{size};
@@ -685,8 +700,8 @@ sub sync { # Synchronization. Main proccess
                     $skipped = 1;
                     next;
                 }
-                
-                #   , 
+
+                # Все проверки прошли, скачиваем
                 my $fetch_file = fetch($url, $k, $self->{file_temp});
                 if ($fetch_file->{status}) {
                     my $size_fact = $fetch_file->{size} || 0;
@@ -695,26 +710,26 @@ sub sync { # Synchronization. Main proccess
                         $total += $size_fact;
                         $dwldd = 1;
                     } else {
-                        debug(sprintf("\t[ ERROR ] Can't fetch file [%s], %s", 
+                        debug(sprintf("\t[ ERROR ] Can't fetch file [%s], %s",
                                 $url
                             ));
                     }
                 } else {
-                    debug(sprintf("\t[ ERROR ] Can't fetch file [%s], %s", 
+                    debug(sprintf("\t[ ERROR ] Can't fetch file [%s], %s",
                             $fetch_file->{code} ? $fetch_file->{code} : 'UNDEFINED',
                             $url
                         ));
                 }
-                
+
             }
-            
-            if ($dwldd) { #       
-                #  : $self->{file_temp}
-                #    : $k
+
+            if ($dwldd) { # Файл скачен и лежит во временном файле
+                # Откуда : $self->{file_temp}
+                # Куда   : $k
                 my $src = $self->{file_temp};
                 my $dst = File::Spec->canonpath(File::Spec->catfile($self->{dir}, $k));
-                
-                #   
+
+                # Создаем директорию азначения
                 my $dir = dirname($dst); # See File::Basename
                 my $mkerr;
                 mkpath($dir, {
@@ -733,8 +748,8 @@ sub sync { # Synchronization. Main proccess
                 }
                 #debug(sprintf("--> %s >>> %s", $src, $dst));
                 #debug(sprintf("--> %s >>> %s", $dst, $dir));
-                
-                #    
+
+                # Переносим файлы по назначению
                 fdelete($dst);
                 unless (mv($src, $dst)) {
                     debug(sprintf("\t[ ERROR ] Can't move file %s to %s", $src, $dst));
@@ -743,31 +758,31 @@ sub sync { # Synchronization. Main proccess
             } else {
                 debug(sprintf("\t[FAILED ] Can't fetch file %s", $k)) unless $skipped;
             }
-            
+
             #debug($mt_l);
         } else {
             debug(sprintf("\t[SKIPPED] Nothing to do for %s", $k));
         }
     }
     debug(sprintf("Received %d bytes", $total));
-    
-    #   MANIFEST
+
+    # Формируем новый MANIFEST
     debug("Creating new manifest");
     my $new_manifest = manifind($self->{dir});
-    
-    #    
+
+    # Отбираем файлы исключая исключения
     foreach my $k (keys %$new_manifest) {
         my $nskip = _skipcheck(\%skips, $k);
         delete $new_manifest->{$k} if $nskip;
         debug(sprintf("> [%s] %s", $nskip ? "SKIPPED" : " ADDED ", $k));
     }
     #debug(Data::Dumper::Dumper($new_manifest));
-    
-    #   
+
+    # Пишем сам файл
     debug("Saving manifest to file ".MANIFEST);
     return 0 unless maniwrite($self->{file_manifest}, $new_manifest);
-    
-    #   META
+
+    # Формируем новый META
     debug("Creating new META file");
     my $new_meta = {
             last_start  => $self->{stamp},
@@ -776,32 +791,32 @@ sub sync { # Synchronization. Main proccess
             uri         => $self->{uri} || 'localhost',
             date        => scalar(localtime(time)),
             status      => 1, # $status,
-                            #  META        
-                            # .    -    .
-                            #   . #468
+                            # статус META выставляется только по факту успешного формирования итоговой структуры
+                            # катаклога. Это изменение отличает мета-файл от только что инициализированного.
+                            # Внесенные изменения см. #468
         };
     return 0 unless write_yaml($self->{file_meta}, $new_meta);
-    
+
     return $status;
 }
-sub check_lock { #  ,    
+sub _check_lock { # Проверка факта, что файл является собственным
     my $self = shift;
     my $file = shift;
     return 0 unless $file && -e $file;
-    
+
     local *RD_LOCK_FILE;
     unless (open(RD_LOCK_FILE, "<", $file)) {
         carp(sprintf("Can't open file %s to read: %s", $file, $!));
         return 0;
     }
-    
+
     my $l;
     chomp($l = <RD_LOCK_FILE>); $l = "" unless defined $l;
     unless (close RD_LOCK_FILE) {
         carp(sprintf("Can't close file %s: %s", $file, $!));
         return 0;
     }
-        
+
     my ($r_pid, $r_stamp, $r_name) = split(/#/, $l);
     if ($r_pid && ($r_pid =~ /^[0-9]{1,11}$/) && kill(0, $r_pid)) {
         return 1 if $self->{pid} == $r_pid;
@@ -810,7 +825,7 @@ sub check_lock { #  ,
 }
 
 # Functions
-sub debug { 
+sub debug {
     print STDOUT @_ ? @_ : '',"\n" if $DEBUG;
     1;
 }
@@ -864,7 +879,7 @@ sub maniread { # Reading data from MANEFEST, MIRRORS and MANEFEST.* files
     # Original see Ext::Utils::maniread
     my $mfile = shift;
     my $skipflag = shift;
-    
+
     my $read = {};
     return $read unless defined($mfile) && (-e $mfile) && (-r $mfile) && (-s $mfile);
     local *M;
@@ -877,7 +892,7 @@ sub maniread { # Reading data from MANEFEST, MIRRORS and MANEFEST.* files
         chomp;
         next if /^\s*#/;
         my($file, $args);
-        
+
         if ($skipflag && $_ =~ /^\s*\!\!perl\/regexp\s*/i) { # Working in SkipMode
             #s/\r//;
             #$_ =~ qr{^\s*\!\!perl\/regexp\s*(?:(?:'([^\\']*(?:\\.[^\\']*)*)')|([^#\s]\S*))?(?:(?:\s*)|(?:\s+(.*?)\s*))$};
@@ -908,7 +923,7 @@ sub maniread { # Reading data from MANEFEST, MIRRORS and MANEFEST.* files
 sub manifind {
     my $dir = shift;
     carp("Can't specified directory") && return {} unless defined($dir) && -e $dir;
-    
+
     my $found = {};
     my $base = File::Spec->canonpath($dir);
     #my ($volume,$sdirs,$sfile) = File::Spec->splitpath( $base );
@@ -918,20 +933,20 @@ sub manifind {
         my $name = File::Spec->abs2rel( $path, $base );
         my $fdir = File::Spec->canonpath($File::Find::dir);
         return if -d $_;
-        
+
         my $key = join("/", File::Spec->splitdir(File::Spec->catfile($name)));
         $found->{$key} = {
                 mtime   => (stat($_))[9] || 0,
                 size    => (-s $_) || 0,
                 dir     => $fdir,
                 path    => $path,
-                file    => File::Spec->abs2rel( $path, $fdir ), 
+                file    => File::Spec->abs2rel( $path, $fdir ),
             };
     };
 
-    # We have to use "$File::Find::dir/$_" in preprocess, because 
+    # We have to use "$File::Find::dir/$_" in preprocess, because
     # $File::Find::name is unavailable.
-    # Also, it's okay to use / here, because MANIFEST files use Unix-style 
+    # Also, it's okay to use / here, because MANIFEST files use Unix-style
     # paths.
     find({
             wanted      => $wanted,
@@ -946,26 +961,26 @@ sub maniwrite {
     carp("Can't specified file") && return 0 unless defined($file);
     carp("Can't specified manifest-hash") && return 0 unless defined($mani) && ref($mani) eq 'HASH';
     my $file_bak = $file.".bak";
-    
+
     rename $file, $file_bak;
     local *M;
-    
+
     unless (open M, ">", $file){
         carp("Can't open file $file: $!");
         rename $file_bak, $file;
         return 0;
     }
-    
+
     # Stamp
     print  M "###########################################\n";
     printf M "# File created at %s\n", scalar(localtime(time()));
     print  M "# Please, do NOT edit this file directly!!\n";
     print  M "###########################################\n\n";
-    
+
     foreach my $f (sort { lc $a cmp lc $b } keys %$mani) {
         my $d = $mani->{$f};
-        my $text = sprintf("%s\t%s\t%s", 
-                $d->{mtime} || 0, 
+        my $text = sprintf("%s\t%s\t%s",
+                $d->{mtime} || 0,
                 $d->{size} || 0,
                 $d->{mtime} ? scalar(localtime($d->{mtime})) : 'UNKNOWN',
             );
@@ -979,50 +994,50 @@ sub maniwrite {
         print M $f, "\t" x $tabs, $text, "\n";
     }
     close M;
-    
+
     unlink $file_bak;
-    
+
     return 1;
 }
 sub fetch($$$) { # Returns structire
     my $url = shift;
     my $obj = shift;
     my $file = shift;
-    
+
     my $ret = {
             status  => 0, # Status
-            mtime   => 0, # Last-Modified in ctime format or 0 
+            mtime   => 0, # Last-Modified in ctime format or 0
             size    => 0, # tContent-length
             code    => 0, # Status code
         };
-    
-    #  URI
+
+    # Форирование URI
     my $uri = new URI($url);
     my $curpath = $uri->path();
     my $newpath = $curpath . (defined $obj ? "/$obj" : ''); $newpath =~ s/\/{2,}/\//;
     $uri->path($newpath);
     $ret->{uri} = $uri->as_string;
-    
-    #   
+
+    # Проверка на файл
     unless (defined $file) {
         carp(sprintf("File to store is not defined"));
         return $ret;
     }
-    
-    #    
+
+    # Первоначальный запрос на существование
     my ($content_type, $document_length, $modified_time, $expires, $server) = head($uri);
     debug(sprintf("HEAD Response:"
         ."\n\tContent-type:\t%s"
         ."\n\tContent-length:\t%s"
         ."\n\tModified:\t%s"
-        ."\n\tServer:\t\t%s", 
-            defined $content_type ? $content_type : '', 
-            defined $document_length ? $document_length : 0, 
-            defined $modified_time ? scalar(localtime($modified_time)) : '', 
+        ."\n\tServer:\t\t%s",
+            defined $content_type ? $content_type : '',
+            defined $document_length ? $document_length : 0,
+            defined $modified_time ? scalar(localtime($modified_time)) : '',
             defined $server ? $server : ''
         ));
-    
-    # .   , 
+
+    # Анализ. Если всё плохо, выход
     if ($document_length) {
         $ret->{size} = $document_length;
     } else {
@@ -1035,7 +1050,7 @@ sub fetch($$$) { # Returns structire
         return $ret;
     }
 
-    #  
+    # Принимаем файл
     fdelete($file);
     my $code = mirror($uri, $file);
     $ret->{code} = $code;
@@ -1044,10 +1059,10 @@ sub fetch($$$) { # Returns structire
             $ret->{status} = 1;
         }
     }
-    
+
     return $ret;
 }
-sub _expire { #   expires
+sub _expire { # Перевод в expires
     my $str = shift || 0;
 
     return 0 unless defined $str;
@@ -1071,12 +1086,12 @@ sub _expire { #   expires
     return $koef * $_map{ $d };
 }
 sub _qrreconstruct {
-    #    (QR-)
-    #    YAML::Type::regexp  YAML::Types,    
-    #  !!
-    #     :
+    # Возвращает регулярное выражение (QR-строку)
+    # Функция позаимствованая из YAML::Type::regexp пакета YAML::Types, немного переделанная для
+    # адаптации нужд!!
+    # На вход подается примерно следующее:
     #    !!perl/regexp (?i-xsm:^\s*(error|fault|no))
-    #    :
+    # это является регуляркой вида:
     #    qr/^\s*(error|fault|no)/i
     my $node = shift;
     return undef unless defined $node;
@@ -1093,15 +1108,17 @@ sub _skipcheck {
     my $sl = shift; # Link to %skip
     my $st = shift; # Test string
     return 0 unless $sl && defined($st) && ref($sl) eq 'HASH';
-    return 1 if exists $sl->{$st} && defined $sl->{$st}; #  ! ..   
-    
-    #          
+    return 1 if exists $sl->{$st} && defined $sl->{$st}; # Исключение нашли! Т.к. нашлось прямое соответствие
+
+    # Пробегаемся по всем значениям и ищем среди них только регулярки
     if (grep {(ref($_) eq 'Regexp') && $st =~ $_} values %$sl) {
-        $sl->{$st} = 1; #        .  
-        return 1 
+        $sl->{$st} = 1; # Для очередной проверки данные проверки будут уже излишними. Оптимизация производительности
+        return 1
     }
 
     return 0; # Not Found
 }
+
 1;
+
 __END__
